@@ -238,7 +238,7 @@ happyFmap1 f m tks = happyThen (m tks) (\a -> happyReturn (f a))
 happyReturn1 :: () => a -> b -> (P a)
 happyReturn1 = \a tks -> (returnP) a
 happyReport' :: () => [(Token)] -> [Happy_Prelude.String] -> ([(Token)] -> (P a)) -> (P a)
-happyReport' = (\tokens expected resume -> happyError tokens)
+happyReport' = (\tokens expected resume -> (happyError) tokens)
 
 happyAbort :: () => [(Token)] -> (P a)
 happyAbort = Happy_Prelude.error "Called abort handler in non-resumptive parser"
@@ -276,7 +276,9 @@ toHeadline t = Headline (toId t) (toContent t)
 toAddress :: String -> Block
 toAddress t = Address (toId t) (head $ words t)
 
-happyError = \tks i -> error ("Parse error in line " ++ show (i::Int) ++ ".\n")
+happyError :: [Token] -> a
+happyError [] = error ("Parse error - no input")
+happyError (t:_) = error ("Parse error - provided input did not match any grammar production rules: " <> show t <> ".")
 
 data ParseResult a
   = ParseOk a
